# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/testing.ipynb.

# %% auto 0
__all__ = ['TEST_IMAGE', 'fixture_directory', 'fixture_path']

# %% ../nbs/testing.ipynb 3
from pathlib import Path

# %% ../nbs/testing.ipynb 4
def fixture_directory() -> Path:
    cwd = Path('.').resolve()
    if cwd.name == 'nbs':
        return cwd / 'fixtures'
    return cwd / 'nbs' / 'fixtures'


def fixture_path(relative_path) -> Path:
    return fixture_directory() / relative_path

# %% ../nbs/testing.ipynb 5
TEST_IMAGE = fixture_path('puppy.jpg')
